/**
 * JSON to Go Struct tests.
 *
 * @author wangkechun [hi@hi-hi.cn]
 *
 * @copyright Crown Copyright 2019
 * @license Apache-2.0
 */
import TestRegister from "../../lib/TestRegister.mjs";

TestRegister.addTests([
    {
        name: "JSON to Go Struct: simple",
        input: JSON.stringify({ a: "1", b: "2", c: "3" }),
        expectedOutput: `type AutoGenerated struct {
    A string \`json:"a"\`
    B string \`json:"b"\`
    C string \`json:"c"\`
}`.replaceAll("    ", "\t"),
        recipeConfig: [
            {
                op: "JSON to Go Struct",
                args: ["AutoGenerated", true, false],
            },
        ],
    },
    {
        name: "JSON to Go Struct: flatten",
        input: JSON.stringify({ a: "1", b: "2", c: { d: "e" } }),
        expectedOutput: `type AutoGenerated struct {
    A string \`json:"a"\`
    B string \`json:"b"\`
    C C \`json:"c"\`
}
type C struct {
    D string \`json:"d"\`
}`.replaceAll("    ", "\t"),
        recipeConfig: [
            {
                op: "JSON to Go Struct",
                args: ["AutoGenerated", true, false],
            },
        ],
    },
    {
        name: "JSON to Go Struct: nest",
        input: JSON.stringify({ a: "1", b: "2", c: { d: "e" } }),
        expectedOutput: `type AutoGenerated struct {
    A string \`json:"a"\`
    B string \`json:"b"\`
    C struct {
        D string \`json:"d"\`
    } \`json:"c"\`
}`.replaceAll("    ", "\t"),
        recipeConfig: [
            {
                op: "JSON to Go Struct",
                args: ["AutoGenerated", false, false],
            },
        ],
    },
]);
